﻿using MedicalDatabaseContracts;
using MedicalDatabaseContracts.Models;
using MedicalDatabaseContracts.SearchModels;
using MedicalDatabaseContracts.ViewModels;
using Microsoft.Extensions.Logging;

namespace MedicalView.Specializations
{
    public partial class FormSpecialization : FormAbstractDetail
    {
        private readonly ILogger<FormSpecialization> _logger;
        private readonly ILogic<Specialization, SpecializationViewModel, SpecializationSearchModel> _logic;
        public FormSpecialization(ILogger<FormSpecialization> logger, ILogic<Specialization, SpecializationViewModel, SpecializationSearchModel> logic)
        {
            InitializeComponent();
            _logger = logger;
            _logic = logic;
        }

        private void ApplyToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (string.IsNullOrEmpty(textBoxName.Text))
            {
                MessageBox.Show("Заполните название", "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            _logger.LogInformation("Сохранение специальности");
            try
            {
                var model = new Specialization
                {
                    Id = ModelId ?? 0,
                    Name = textBoxName.Text,
                    IsPediatric = checkBoxIsPediatric.Checked,
                    IsTherapeutic = checkBoxIsTherapeutic.Checked
                };
                var operationResult = ModelId.HasValue ? _logic.Update(model) : _logic.Create(model);
                if (!operationResult)
                {
                    throw new Exception("Ошибка при сохранении. Дополнительная информация в логах.");
                }
                MessageBox.Show("Сохранение прошло успешно", "Сообщение", MessageBoxButtons.OK, MessageBoxIcon.Information);
                DialogResult = DialogResult.OK;
                Close();
            }
            catch (Exception ex)
            {
                _logger.LogError(ex, "Ошибка сохранения специальности");
                MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void CancelToolStripMenuItem_Click(object sender, EventArgs e)
        {
            Cancel();
        }

        private void FormSpecialization_Load(object sender, EventArgs e)
        {
            if (ModelId.HasValue)
            {
                try
                {
                    _logger.LogInformation("Получение диагноза");
                    var view = _logic.ReadElement(ModelId.Value);
                    if (view != null)
                    {
                        textBoxName.Text = view.Name;
                        checkBoxIsPediatric.Checked = view.IsPediatric;
                        checkBoxIsTherapeutic.Checked = view.IsTherapeutic;
                    }
                }
                catch (Exception ex)
                {
                    _logger.LogError(ex, "Ошибка получения специальности");
                    MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
            }
        }
    }
}
